# mypy-boto3-clouddirectory

[![PyPI - mypy-boto3-clouddirectory](https://img.shields.io/pypi/v/mypy-boto3-clouddirectory.svg?color=blue)](https://pypi.org/project/mypy-boto3-clouddirectory)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-clouddirectory.svg?color=blue)](https://pypi.org/project/mypy-boto3-clouddirectory)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-clouddirectory](#mypy-boto3-clouddirectory)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)

Type annotations for
[boto3.CloudDirectory 1.14.0](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/clouddirectory.html#CloudDirectory) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `CloudDirectory` service.

```bash
python -m pip install boto3-stubs[clouddirectory]
```

Use `boto3` with `mypy_boto3_clouddirectory` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_clouddirectory import CloudDirectoryClient

# Now mypy can check if your code is valid.
client: CloudDirectoryClient = boto3.client("clouddirectory")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CloudDirectoryClient = session.client("clouddirectory")



# Annotated paginators are included as well

import mypy_boto3_clouddirectory.paginator as clouddirectory_paginators

list_applied_schema_arns_paginator: clouddirectory_paginators.ListAppliedSchemaArnsPaginator = client.get_paginator("list_applied_schema_arns")
list_attached_indices_paginator: clouddirectory_paginators.ListAttachedIndicesPaginator = client.get_paginator("list_attached_indices")
list_development_schema_arns_paginator: clouddirectory_paginators.ListDevelopmentSchemaArnsPaginator = client.get_paginator("list_development_schema_arns")
list_directories_paginator: clouddirectory_paginators.ListDirectoriesPaginator = client.get_paginator("list_directories")
list_facet_attributes_paginator: clouddirectory_paginators.ListFacetAttributesPaginator = client.get_paginator("list_facet_attributes")
list_facet_names_paginator: clouddirectory_paginators.ListFacetNamesPaginator = client.get_paginator("list_facet_names")
list_incoming_typed_links_paginator: clouddirectory_paginators.ListIncomingTypedLinksPaginator = client.get_paginator("list_incoming_typed_links")
list_index_paginator: clouddirectory_paginators.ListIndexPaginator = client.get_paginator("list_index")
list_managed_schema_arns_paginator: clouddirectory_paginators.ListManagedSchemaArnsPaginator = client.get_paginator("list_managed_schema_arns")
list_object_attributes_paginator: clouddirectory_paginators.ListObjectAttributesPaginator = client.get_paginator("list_object_attributes")
list_object_parent_paths_paginator: clouddirectory_paginators.ListObjectParentPathsPaginator = client.get_paginator("list_object_parent_paths")
list_object_policies_paginator: clouddirectory_paginators.ListObjectPoliciesPaginator = client.get_paginator("list_object_policies")
list_outgoing_typed_links_paginator: clouddirectory_paginators.ListOutgoingTypedLinksPaginator = client.get_paginator("list_outgoing_typed_links")
list_policy_attachments_paginator: clouddirectory_paginators.ListPolicyAttachmentsPaginator = client.get_paginator("list_policy_attachments")
list_published_schema_arns_paginator: clouddirectory_paginators.ListPublishedSchemaArnsPaginator = client.get_paginator("list_published_schema_arns")
list_tags_for_resource_paginator: clouddirectory_paginators.ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
list_typed_link_facet_attributes_paginator: clouddirectory_paginators.ListTypedLinkFacetAttributesPaginator = client.get_paginator("list_typed_link_facet_attributes")
list_typed_link_facet_names_paginator: clouddirectory_paginators.ListTypedLinkFacetNamesPaginator = client.get_paginator("list_typed_link_facet_names")
lookup_policy_paginator: clouddirectory_paginators.LookupPolicyPaginator = client.get_paginator("lookup_policy")
```

## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_clouddirectory` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python
import boto3

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("clouddirectory")

session_client = boto3.Session().client("clouddirectory")
```